aboutsummaryrefslogtreecommitdiff
path: root/src/common/linux
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/linux')
-rw-r--r--src/common/linux/http_upload.cc15
-rw-r--r--src/common/linux/http_upload.h9
2 files changed, 12 insertions, 12 deletions
diff --git a/src/common/linux/http_upload.cc b/src/common/linux/http_upload.cc
index 4492fe84..d49f2276 100644
--- a/src/common/linux/http_upload.cc
+++ b/src/common/linux/http_upload.cc
@@ -56,7 +56,8 @@ static const char kUserAgent[] = "Breakpad/1.0 (Linux)";
// static
bool HTTPUpload::SendRequest(const string &url,
const map<string, string> &parameters,
- const map<string, string> &files,
+ const string &upload_file,
+ const string &file_part_name,
const string &proxy,
const string &proxy_user_pwd,
const string &ca_certificate_file,
@@ -134,13 +135,11 @@ bool HTTPUpload::SendRequest(const string &url,
CURLFORM_COPYCONTENTS, iter->second.c_str(),
CURLFORM_END);
- // Add form files.
- for (iter = files.begin(); iter != files.end(); ++iter) {
- (*curl_formadd)(&formpost, &lastptr,
- CURLFORM_COPYNAME, iter->first.c_str(),
- CURLFORM_FILE, iter->second.c_str(),
- CURLFORM_END);
- }
+ // Add form file.
+ (*curl_formadd)(&formpost, &lastptr,
+ CURLFORM_COPYNAME, file_part_name.c_str(),
+ CURLFORM_FILE, upload_file.c_str(),
+ CURLFORM_END);
(*curl_easy_setopt)(curl, CURLOPT_HTTPPOST, formpost);
diff --git a/src/common/linux/http_upload.h b/src/common/linux/http_upload.h
index 4f0e452f..6dd36ea0 100644
--- a/src/common/linux/http_upload.h
+++ b/src/common/linux/http_upload.h
@@ -45,9 +45,9 @@ using std::map;
class HTTPUpload {
public:
// Sends the given sets of parameters and files as a multipart POST
// request to the given URL.
// Each key in |files| is the name of the file part of the request
// (i.e. it corresponds to the name= attribute on an <input type="file">.
// Parameter names must contain only printable ASCII characters,
// and may not contain a quote (") character.
@@ -60,7 +60,8 @@ class HTTPUpload {
// returned in error_description.
static bool SendRequest(const string &url,
const map<string, string> &parameters,
- const map<string, string> &files,
+ const string &upload_file,
+ const string &file_part_name,
const string &proxy,
const string &proxy_user_pwd,
const string &ca_certificate_file,
@@ -45,9 +45,9 @@ using std::map;
class HTTPUpload {
public:
- // Sends the given sets of parameters and files as a multipart POST
- // request to the given URL.
- // Each key in |files| is the name of the file part of the request
+ // Sends the given set of parameters, along with the contents of
+ // upload_file, as a multipart POST request to the given URL.
+ // file_part_name contains the name of the file part of the request
// (i.e. it corresponds to the name= attribute on an <input type="file">.
// Parameter names must contain only printable ASCII characters,